``wool``
==========

This project aims to demonstrate a few things:

-  A ``caravel``-wrapped ``openlane2`` digital design flow
-  Mixed-signal layout and integration with ``gdsfactory``
-  Cosimulation between analogue and digital design flows using the ``piel`` design flow.
-  Be tape-out and experimentally validated in a MPW.
